==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System.Design/System.Windows.Forms.Design/ImageListImageEditor.cs <==
//
// System.Windows.Forms.Design.ImageListImageEditor.cs
//
// Author:
//	Atsushi Enomoto (atsushi@ximian.com)
//
// Copyright (C) 2007 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0 && DRAWING_DESIGN_DEP

using System;
using System.ComponentModel;
using System.Drawing.Design;

namespace System.Windows.Forms.Design
{
	public class ImageListImageEditor : ImageEditor
	{
		public ImageListImageEditor ()
		{
		}

		[MonoTODO]
		public override object EditValue (ITypeDescriptorContext context, IServiceProvider provider, object value)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		protected override string GetFileDialogDescription ()
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		protected override Type [] GetImageExtenders ()
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public override bool GetPaintValueSupported (ITypeDescriptorContext context)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public override void PaintValue (PaintValueEventArgs e)
		{
			throw new NotImplementedException ();
		}
	}
}

#endif

==> mono-4.4.0.148.tar.bz2: mono-4.4.0/mcs/class/System.Design/System.Windows.Forms.Design/ImageListImageEditor.cs <==
//
// System.Windows.Forms.Design.ImageListImageEditor.cs
//
// Author:
//	Atsushi Enomoto (atsushi@ximian.com)
//
// Copyright (C) 2007 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if DRAWING_DESIGN_DEP

using System;
using System.ComponentModel;
using System.Drawing.Design;

namespace System.Windows.Forms.Design
{
	public class ImageListImageEditor : ImageEditor
	{
		public ImageListImageEditor ()
		{
		}

		[MonoTODO]
		public override object EditValue (ITypeDescriptorContext context, IServiceProvider provider, object value)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		protected override string GetFileDialogDescription ()
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		protected override Type [] GetImageExtenders ()
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public override bool GetPaintValueSupported (ITypeDescriptorContext context)
		{
			throw new NotImplementedException ();
		}

		[MonoTODO]
		public override void PaintValue (PaintValueEventArgs e)
		{
			throw new NotImplementedException ();
		}
	}
}

#endif
